"""quixote.init

Stuff for setting up Quixote prior to entering the main loop.

Note that if you're using ZODB, you must import ZODB before installing
Quixote's import hooks -- we're not sure why this is, but it is.  This
applies to 'init_quixote()' and 'install_imphooks()'.
"""

# created 2000/08/01, GPW

__revision__ = "$Id: init.py,v 1.7 2001/05/29 20:19:35 gward Exp $"

def init_quixote ():
    install_imphooks()

def install_imphooks ():
    from quixote import imphooks
    imphooks.install()
